base

package
v0.0.0-...-d94c480 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 21, 2016 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BaseModel

type BaseModel struct {
	FileName   string
	ClassIndex int
	Data       [][]float64

	AttributeNormalisation bool
	// contains filtered or unexported fields
}

BaseModel contains basic attributes and methods to get going

func (*BaseModel) GetClassString

func (model *BaseModel) GetClassString(value float64) string

GetClassString returns the category of the given normalised value returns zero string if not found

func (*BaseModel) PrepareModel

func (model *BaseModel) PrepareModel() error

PrepareModel will load the data from the file given and Normalise the data if required

Jump to