Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BaseModel ¶
type BaseModel struct {
FileName string
ClassIndex int
Data [][]float64
AttributeNormalisation bool
// contains filtered or unexported fields
}
BaseModel contains basic attributes and methods to get going
func (*BaseModel) GetClassString ¶
GetClassString returns the category of the given normalised value returns zero string if not found
func (*BaseModel) PrepareModel ¶
PrepareModel will load the data from the file given and Normalise the data if required
Click to show internal directories.
Click to hide internal directories.